==> igniteui-react-16.16.2.tgz: package/esm5/lib/DockManagerResourceStrings.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
var DockManagerResourceStrings = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockManagerResourceStrings, _super);
    function DockManagerResourceStrings() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.c = null;
        return _this;
    }
    Object.defineProperty(DockManagerResourceStrings.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "nativeElement", {
        get: function () {
            return this.c;
        },
        set: function (a) {
            this.c = a;
            this.a.d = this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "e", {
        get: function () {
            var ret_ = this.b.c("close");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("close", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "l", {
        get: function () {
            var ret_ = this.b.c("pin");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("pin", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "m", {
        get: function () {
            var ret_ = this.b.c("unpin");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("unpin", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "g", {
        get: function () {
            var ret_ = this.b.c("maximize");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("maximize", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "h", {
        get: function () {
            var ret_ = this.b.c("minimize");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("minimize", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "i", {
        get: function () {
            var ret_ = this.b.c("moreOptions");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("moreOptions", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "j", {
        get: function () {
            var ret_ = this.b.c("moreTabs");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("moreTabs", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "k", {
        get: function () {
            var ret_ = this.b.c("panes");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("panes", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "f", {
        get: function () {
            var ret_ = this.b.c("documents");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("documents", value_);
        },
        enumerable: false,
        configurable: true
    });
    DockManagerResourceStrings.$t = markType(DockManagerResourceStrings, 'DockManagerResourceStrings');
    return DockManagerResourceStrings;
}(Base));
export { DockManagerResourceStrings };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/DockManagerResourceStrings.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
var DockManagerResourceStrings = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockManagerResourceStrings, _super);
    function DockManagerResourceStrings() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.c = null;
        return _this;
    }
    Object.defineProperty(DockManagerResourceStrings.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "nativeElement", {
        get: function () {
            return this.c;
        },
        set: function (a) {
            this.c = a;
            this.a.o = this.c;
        },
        enumerable: false,
        configurable: true
    });
    DockManagerResourceStrings.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DockManagerResourceStrings.prototype, "e", {
        get: function () {
            var ret_ = this.b.n("close");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("close", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "l", {
        get: function () {
            var ret_ = this.b.n("pin");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("pin", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "m", {
        get: function () {
            var ret_ = this.b.n("unpin");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("unpin", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "g", {
        get: function () {
            var ret_ = this.b.n("maximize");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("maximize", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "h", {
        get: function () {
            var ret_ = this.b.n("minimize");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("minimize", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "i", {
        get: function () {
            var ret_ = this.b.n("moreOptions");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("moreOptions", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "j", {
        get: function () {
            var ret_ = this.b.n("moreTabs");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("moreTabs", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "k", {
        get: function () {
            var ret_ = this.b.n("panes");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("panes", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerResourceStrings.prototype, "f", {
        get: function () {
            var ret_ = this.b.n("documents");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("documents", value_);
        },
        enumerable: false,
        configurable: true
    });
    DockManagerResourceStrings.$t = markType(DockManagerResourceStrings, 'DockManagerResourceStrings');
    return DockManagerResourceStrings;
}(Base));
export { DockManagerResourceStrings };
